from setuptools import setup, find_packages

setup(name='abylai_zhumart_20051',
      version='0.0',
      description='Math library',
      packages=find_packages(include=['abylai_zhumart_20051']),
      author_email='cstawer2005@mail.ru',
      zip_safe=False)
